#!/bin/bash

#
#  Meta install script for STM32-toolchain.
#  written by Gregor Rebel 2011-04-11.
#  
#  This script will automatically run all install_* scripts in current folder.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

Script="$1"

source scripts/installFuncs.sh

if [ "$Script" == "" ]; then
  Files=`ls install_*`

  # prepare for installation
  rm 2>/dev/null ErrorOccured AllInstallsOK
  echo "" >cleanup.sh
  if [ ! -d Logs ]; then
    mkdir Logs
  fi
  for Script in $Files; do
    if [ ! -e Logs/$Script.log ]; then
      echo "" >Logs/$Script.log
    fi
  done
  
  # createLinks
  cat <<END_OF_LINKS >scripts/createLinks.sh #{
#!/bin/bash
# createLinks.sh created `date`
#
# This script is part of ToolChain_STM32

if [ ! -d extensions.active ]; then
  mkdir extensions.active
fi
cd extensions.active
if [ ! -e readme.txt ]; then
  echo <<"END_OF_README" >readme.txt

                               ToolChain_STM32

                         Extension to central makefile

                       written by Gregor Rebel 2010-`date +%Y`


All makefile.* files in this folder are automatically being included by ../makefile

The idea of this folder is to activate certain extensions by creating symbolic
links to files inside ../extensions

Example:

activate.600_example_leds.sh
activate.100_board_olimex_p107.sh
./compile.sh

END_OF_README
fi

MakefilesPresent=\`ls | grep makefile.\`
cd ..
if [ "\$MakefilesPresent" == "" ]; then
pwd
  ./extensions/activate.600_example_leds.sh
  ./extensions/activate.100_board_olimex_p107.sh
fi

rm 2>/dev/null extensions;  ln -sv \$Source/ToolChain_STM32/ToolChain/extensions/  extensions

cd additionals

END_OF_LINKS
#}
  if [ -d ../Template/additionals/ ]; then
    rm 2>/dev/null ../Template/additionals/*
  else
    mkdir ../Template/additionals
  fi
  if [ -d extensions/ ]; then
    rm 2>/dev/null extensions/*
  else
    mkdir extensions
  fi
  
  # run all install scripts
  echo "Runing all install scripts."
  echo "You may check progress by inspecting log files via"
  echo "  tail -f `pwd`/Logs/*"
  echo ""
  for Script in $Files; do
    if [ ! -e ErrorOccured ]; then
      Error=""
      $0 $Script || Error="1"
      if [ "$Error" != "" ]; then
        echo "ERROR occured during $Script !"
        exit 6
      fi
    fi
  done
  
  cp ../Version scripts/
#X  echo 'cd ..; echo "ToolChain_STM32 v`cat _/Version`"' >>scripts/createLinks.sh

  # remove temporary files
  chmod +x cleanup.sh
  ./cleanup.sh
  
  # installation finished successfully
  touch AllInstallsOK
  addLine $HOME/.bashrc "source `pwd`/scripts/SourceMe.sh"
  addLine scripts/SourceMe.sh "alias commit='git pull && git commit'"
  addLine scripts/SourceMe.sh "export PATH=\"`pwd`/extensions/:\$PATH\""
  source scripts/SourceMe.sh
  OldDir="`pwd`"
  cd ../Template
  ./createLinks.sh
  cd "$OldDir"
  cd ..
  
  echo ""
  echo "All tools have been installed successfully."
  echo "Note: Your .bashrc has been updated."
  echo ""
  echo "Next steps:"
  echo "  (1) Connect JTAG programmer (e.g. ARM-USB-TINY-H) to your computer"
  echo "  (2) Connect your ARM prototype board (e.g. STM32-P107) to JTAG programmer"
  echo "  (3) Start a new shell!"
  echo "  (4) cd `pwd`"
  echo "  (5) ./createNewProject.pl Test ItsMe"
  echo "  (6) cd Test"
  echo "  (7) ./compile.sh"
  echo ""
  echo "  Have fun! :-)"
else
  echo -n "running `pwd`/$Script.."
  dir Logs
  echo "$Script started @`date`" >Logs/$Script.log
  ./$Script >Logs/$Script.log 2>Logs/$Script.err && OK="1"
  if [ "$OK" == "1" ]; then
    echo "OK"
  else
    echo "ERROR"
    echo ""
    echo "Check logfiles:"
    find `pwd`/Logs/ -name $Script.* -exec echo "less {}" \;
    touch ErrorOccured
    exit 5
  fi
fi
